@@ -12,15 +12,15 @@ class Date:
         # The original request
         self._original = date
         if tz:
-            tz = pytz.timezone(tz)
+            tz = pytz.timezone(str(tz))
 
         # Determinal starting date.
         if type(date) in (types.StringType, types.UnicodeType):
             '''
             The date is a string and needs to be converted into a <dict> for processesing
             '''
-            date = date.lower()
-            res = TIMESTRING_RE.search(date.strip())
+            _date = date.lower()
+            res = TIMESTRING_RE.search(_date.strip())
 
             if res:
                 date = res.groupdict()
@@ -28,11 +28,24 @@ class Date:
                 raise ValueError('Invlid date string >> %s' % date)
 
             date = dict((k, v if type(v) is str else v) for k, v in date.iteritems() if v)
-            #print dict(map(lambda a: (a, date.get(a)), filter(lambda a: date.get(a), date)))
+            #print _date, dict(map(lambda a: (a, date.get(a)), filter(lambda a: date.get(a), date)))
 
         if isinstance(date, dict):
             # Initial date.
-            new_date = datetime(*time.localtime()[:3]).replace(tzinfo=tz)
+            new_date = datetime(*time.localtime()[:3])
+            if tz:
+                #
+                # The purpose here is to adjust what day it is based on the timezeone
+                #
+                ts = datetime.now()
+                # Daylight savings === second Sunday in March and reverts to standard time on the first Sunday in November
+                # Monday is 0 and Sunday is 6.
+                # 14 days - dst_start.weekday()
+                dst_start = datetime(ts.year, 3, 1, 2, 0, 0) + timedelta(13 - datetime(ts.year, 3, 1).weekday())
+                dst_end = datetime(ts.year, 11, 1, 2, 0, 0) + timedelta(6 - datetime(ts.year, 11, 1).weekday())
+
+                ts = ts + tz.utcoffset(new_date, is_dst=(dst_start < ts < dst_end))
+                new_date = datetime(ts.year, ts.month, ts.day)
 
             # !number of (days|...) (ago)?
             if date.get('num') or date.get('delta'):
@@ -102,7 +115,7 @@ class Date:
                 elif dow == 'tomorrow':
                     new_date = new_date + timedelta(days=1)
                 elif dow == 'now':
-                    new_date = datetime(*time.localtime()[:5]).replace(tzinfo=tz)
+                    new_date = datetime(*time.localtime()[:5])
 
             # !year
             year = [date.get(key) for key in ('year', 'year_2', 'year_3', 'year_4', 'year_5', 'year_6') if date.get(key)]
@@ -113,7 +126,7 @@ class Date:
                 new_date = new_date.replace(year=y)
 
             # !month
-            month = [date.get(key) for key in ('month', 'month_2', 'month_3', 'month_4') if date.get(key)]
+            month = [date.get(key) for key in ('month', 'month_1', 'month_2', 'month_3', 'month_4') if date.get(key)]
             if month:
                 new_date = new_date.replace(day=1)
                 new_date = new_date.replace(month=int(max(month)) if re.match('^\d+$', max(month)) else dict(january=1, february=2, march=3, april=4, june=6, july=7, august=8, september=9, october=10, november=11, december=12, jan=1, feb=2, mar=3, apr=4, may=5, jun=6, jul=7, aug=8, sep=9, sept=9, oct=10, nov=11, dec=12).get(max(month),  new_date.month))
@@ -151,17 +164,20 @@ class Date:
             self.date = new_date
 
         elif type(date) in (types.IntType, types.LongType, types.FloatType) and re.match('^\d{10}$', date):
-            self.date = datetime.fromtimestamp(int(date)).replace(tzinfo=tz)
+            self.date = datetime.fromtimestamp(int(date))
 
         elif isinstance(date, datetime):
             self.date = date
 
         elif date is None:
-            self.date = datetime.now(tz)
+            self.date = datetime.now()
 
         else:
             # Set to the current date Y, M, D, H0, M0, S0
-            self.date = datetime(*time.localtime()[:3]).replace(tzinfo=tz)
+            self.date = datetime(*time.localtime()[:3])
+
+        if tz:
+            self.date = self.date.replace(tzinfo=tz)
 
         # end if type(date) is types.DictType: and self.date.hour == 0:
         if offset and isinstance(offset, dict):
@@ -286,7 +302,7 @@ class Date:
         return time.mktime(self.date.timetuple())
 
     def to_mysql(self):
-        return "date '%s'" % str(self.date)
+        return "date '%s'" % str(self.format("%Y-%m-%d %H:%M:%S"))
 
     def to_postgresql(self):
         return "'%s'::date" % str(self.date)
