@@ -2,6 +2,8 @@ from timestring.Range import Range
 from timestring.Date import Date
 from datetime import datetime, timedelta
 import unittest
+import os
+import time
 
 
 class timestringTests(unittest.TestCase):
@@ -28,6 +30,18 @@ class timestringTests(unittest.TestCase):
         #
         # RANGE
         #
+        r = Range('From 04/17/13 04:18:00 to 05/01/13 17:01:00', tz='US/Central')
+        self.assertEqual(r.start.year, 2013)
+        self.assertEqual(r.start.month, 4)
+        self.assertEqual(r.start.day, 17)
+        self.assertEqual(r.start.hour, 4)
+        self.assertEqual(r.start.minute, 18)
+        self.assertEqual(r.end.year, 2013)
+        self.assertEqual(r.end.month, 5)
+        self.assertEqual(r.end.day, 1)
+        self.assertEqual(r.end.hour, 17)
+        self.assertEqual(r.end.minute, 1)
+
         _range = Range("between january 15th at 3 am and august 5th 5pm")
         self.assertEqual(_range[0].year, now.year)
         self.assertEqual(_range[0].month, 1)
@@ -61,6 +75,30 @@ class timestringTests(unittest.TestCase):
         self.assertEqual(Date("05/23/2012").month, 5)
         self.assertEqual(Date("01/10/2015 at 7:30pm").month, 1)
         self.assertEqual(Date("today").day, now.day)
+        self.assertEqual(Range('january')[0].month, 1)
+        self.assertEqual(Range('january')[0].day, 1)
+        self.assertEqual(Range('january')[0].hour, 0)
+        self.assertEqual(Range('january')[1].month, 2)
+        self.assertEqual(Range('january')[1].day, 1)
+        self.assertEqual(Range('january')[1].hour, 0)
+        self.assertEqual(Range('2010')[0].year, 2010)
+        self.assertEqual(Range('2010')[0].month, 1)
+        self.assertEqual(Range('2010')[0].day, 1)
+        self.assertEqual(Range('2010')[0].hour, 0)
+        self.assertEqual(Range('2010')[1].year, 2011)
+        self.assertEqual(Range('2010')[1].month, 1)
+        self.assertEqual(Range('2010')[1].day, 1)
+        self.assertEqual(Range('2010')[1].hour, 0)
+
+        self.assertEqual(Range('january 2011')[0].year, 2011)
+        self.assertEqual(Range('january 2011')[0].month, 1)
+        self.assertEqual(Range('january 2011')[0].day, 1)
+        self.assertEqual(Range('january 2011')[0].hour, 0)
+        self.assertEqual(Range('january 2011')[1].year, 2011)
+        self.assertEqual(Range('january 2011')[1].month, 2)
+        self.assertEqual(Range('january 2011')[1].day, 1)
+        self.assertEqual(Range('january 2011')[1].hour, 0)
+
 
     def test_this(self):
         now = datetime.now()
@@ -220,6 +258,8 @@ class timestringTests(unittest.TestCase):
 
 
 def main():
+    os.environ['TZ'] = 'UTC'
+    time.tzset()
     unittest.main()
 
 
